package
Version:
v0.0.0-...-7aba239
Opens a new window with list of versions in this module.
Published: Apr 1, 2025
License: Apache-2.0, MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func DefaultLogFilePath() string
Init initializes logger with a logPath
If logPath is nil then log file is created in os.UserHomeDir
func Printf(fmt string, v ...interface{})
func Println(v ...interface{})
Source Files
¶
Click to show internal directories.
Click to hide internal directories.