package
Version:
v0.0.0-...-7aba239
Opens a new window with list of versions in this module.
Published: Apr 1, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type FS interface {
FileExists(path string) bool
}
Wrapps OS file methods in FS interface
Source Files
¶
Click to show internal directories.
Click to hide internal directories.